@@ -1,5 +1,5 @@
 
-context("babsim.hospital function valuation")
+
 
 test_that("test funWrapOptimizeSim", {
   require("simmer")
@@ -7,9 +7,9 @@ test_that("test funWrapOptimizeSim", {
   x <- getStartParameter()
   data <- getObkData()
   conf <- babsimToolsConf()
-  conf$seed = 123
+  conf$seed <- 123
   y1 <- funWrapOptimizeSim(x, conf = conf, data = data)
-  conf$seed = 123
+  conf$seed <- 123
   y2 <- funWrapOptimizeSim(x, conf = conf, data = data)
- 	expect_equal(y1, y2)
- })
+  expect_equal(y1, y2)
+})
